@@ -23,15 +23,35 @@ SHARED_HEADERS = {
 
 RIDE_URL = 'https://services.universalorlando.com/api/pointsofinterest/rides'
 SHOW_URL = 'https://services.universalorlando.com/api/pointsofinterest/Shows'
+HOUR_URL = 'https://services.universalorlando.com/api/venues/{0}/hours'
+
 class UniversalPark(Park):
     def __init__(self):
         super(UniversalPark, self).__init__()
-
+        
     def _buildPark(self):
         token = self._get_token()
         ride_page = self._get_request(token, RIDE_URL)
         show_page = self._get_request(token, SHOW_URL)
+        hour_page = self._get_request(token, HOUR_URL.format(self.getId()))
         
+        for date in hour_page:
+            if datetime.date.fromisoformat(date['Date']) == datetime.date.today():
+                if date['VenueStatus'] == 'Closed Due to Capacity':
+                    self.Capacity = True
+                    break
+                else:
+                    self.Capacity = False
+                    break
+        
+        for date in hour_page:
+                open_time, close_time = datetime.datetime.fromisoformat(date['OpenTimeString']), datetime.datetime.fromisoformat(date['CloseTimeString'])
+                if open_time < datetime.datetime.now().astimezone() < close_time:
+                    self.set_open()
+                    break
+                else:
+                    self.set_closed()
+                    break
         
         for ride in ride_page['Results']:
             if ride['VenueId'] == self.getId():
@@ -73,6 +93,7 @@ class UniversalPark(Park):
             attraction.setStatus('Capacity')
         elif ride['WaitTime'] == -4:
             attraction.setClosed()
+            attraction.setTime(-1)
             attraction.setStatus('Weather')
         elif ride['WaitTime'] < 0:
             attraction.setClosed()
